Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1769)

Unified Diff: net/http/http_server_properties_impl_unittest.cc

Issue 2070203002: Remove unused HttpServerProperites::ClearAlternativeServices (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@AltSvcClear
Patch Set: fix Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/http/http_server_properties_impl.cc ('k') | net/http/http_server_properties_manager.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/http/http_server_properties_impl_unittest.cc
diff --git a/net/http/http_server_properties_impl_unittest.cc b/net/http/http_server_properties_impl_unittest.cc
index ea6177b83ad30718deb306aef9e7e1ec0294af69..9bbc183ded1c3ea10a2b0e24a4d5ec90858647ca 100644
--- a/net/http/http_server_properties_impl_unittest.cc
+++ b/net/http/http_server_properties_impl_unittest.cc
@@ -776,7 +776,8 @@ TEST_F(AlternateProtocolServerPropertiesTest, AlternativeServiceWithScheme) {
EXPECT_EQ(2u, impl_.GetAlternativeServices(http_server).size());
// Clear Alt-Svc list for |http_server|.
- impl_.ClearAlternativeServices(http_server);
+ impl_.SetAlternativeServices(http_server, AlternativeServiceInfoVector());
+
EXPECT_EQ(0u, impl_.GetAlternativeServices(http_server).size());
EXPECT_EQ(2u, impl_.GetAlternativeServices(https_server).size());
}
@@ -800,7 +801,7 @@ TEST_F(AlternateProtocolServerPropertiesTest, ClearAlternativeServices) {
EXPECT_EQ(alternative_service1, it->second[0].alternative_service);
EXPECT_EQ(alternative_service2, it->second[1].alternative_service);
- impl_.ClearAlternativeServices(test_server);
+ impl_.SetAlternativeServices(test_server, AlternativeServiceInfoVector());
EXPECT_TRUE(map.empty());
}
@@ -837,9 +838,9 @@ TEST_F(AlternateProtocolServerPropertiesTest, ClearBroken) {
impl_.MarkAlternativeServiceBroken(alternative_service);
ASSERT_TRUE(HasAlternativeService(test_server));
EXPECT_TRUE(impl_.IsAlternativeServiceBroken(alternative_service));
// ClearAlternativeServices should leave a broken alternative service marked
// as such.
- impl_.ClearAlternativeServices(test_server);
+ impl_.SetAlternativeServices(test_server, AlternativeServiceInfoVector());
EXPECT_TRUE(impl_.IsAlternativeServiceBroken(alternative_service));
}
@@ -908,7 +909,8 @@ TEST_F(AlternateProtocolServerPropertiesTest, ClearCanonical) {
1234);
SetAlternativeService(canonical_server, canonical_alternative_service);
- impl_.ClearAlternativeServices(canonical_server);
+ impl_.SetAlternativeServices(canonical_server,
+ AlternativeServiceInfoVector());
EXPECT_FALSE(HasAlternativeService(test_server));
}
« no previous file with comments | « net/http/http_server_properties_impl.cc ('k') | net/http/http_server_properties_manager.h » ('j') | no next file with comments »
@@ -837,9 +838,9 @@ TEST_F(AlternateProtocolServerPropertiesTest, ClearBroken) {
ASSERT_TRUE(HasAlternativeService(test_server));
EXPECT_TRUE(impl_.IsAlternativeServiceBroken(alternative_service));
- // ClearAlternativeServices should leave a broken alternative service marked
+ // SetAlternativeServices should leave a broken alternative service marked
// as such.

Powered by Google App Engine
This is Rietveld 408576698